from a4e.sdk import AgentFactory
from autogen_agentchat.agents import AssistantAgent

async def create_agent(model_client, agent_id):
    """
    Create the agent instance

    Args:
        model_client: The LLM client
        agent_id: The ID of the agent
    """
    return await AgentFactory.create_agent(
        agent_path=agent_id,
        model_client=model_client
    )
