{
  "id": {{ agent_id|tojson }},
  "name": {{ display_name|tojson }},
  "shortDescription": {{ description|tojson }},
  "description": {{ description|tojson }},
  "avatar": "",
  "icon": "",
  "category": {{ category|tojson }},
  "rating": 0.0,
  "reviewCount": 0,
  "featured": false,
  "tags": [],
  "capabilities": [],
  "pricing": "free",
  "author": "Unknown",
  "version": "1.0.0",
  "status": "draft",
  "longDescription": {{ description|tojson }},
  "reviews": []
}
